Struct RealParameter

pub struct RealParameter {
    pub(crate) name: CapeStringImpl,
    description: CapeStringImpl,
    is_input: bool,
    shared_unit_data: Rc<RefCell<SharedUnitData>>,
    pub(crate) value: f64,
    default_value: f64,
    minimum_value: f64,
    maximum_value: f64,
    dimensionality: Vec<f64>,
    cobia_object_data: RealParameterCobiaObjectData,
}
The RealParameter class implements a CAPE-OPEN 1.2 real parameter.

Parameters must implement the ICapeIdentification and ICapeParameter interfaces. In addition, real parameters must implement the ICapeRealParameter interface.

This implementation can be used for both input and output parameters. Input parameters can be set by the user, while output parameters are set by the unit operation.

The parameter is allowed to have a missing value, but for input parameters this is considered invalid.

Any other invalid values (outside the bounds of the parameter) will raise an error when set. Therefore, any parameter for which the value is not missing, is valid.

Fields

name: CapeStringImpl

The name of the parameter

description: CapeStringImpl

The description of the parameter

is_input: bool

Indicates whether this parameter is an input (true) or an output (false)

shared_unit_data: Rc<RefCell<SharedUnitData>>

Shared data for the unit, containing unit-specific information

value: f64

The current value of the parameter

default_value: f64

Default value of the parameter

minimum_value: f64

Minimum value of the parameter

maximum_value: f64

Maximum value of the parameter

dimensionality: Vec<f64>

Dimensionality of the parameter

cobia_object_data: RealParameterCobiaObjectData

Cobia object data for this object, which contains generated code to provide the native COBIA interfaces

Implementations

Source

impl RealParameter

fn create_instance( _real_parameter_boxed_ptr: *mut *mut ICapeInterface, name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: f64, minimum_value: f64, maximum_value: f64, dimensionality: Vec<f64>, ) -> CapeResult

pub(crate) fn create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: f64, minimum_value: f64, maximum_value: f64, dimensionality: Vec<f64>, ) -> T

Create a new instance of the object and return a smart pointer to it

This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.

pub(crate) fn try_create<T: CapeSmartPointer>( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: f64, minimum_value: f64, maximum_value: f64, dimensionality: Vec<f64>, ) -> Result<T, COBIAError>

Create a new instance of the object and return a smart pointer to it

This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.

pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self

Get a reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self

Get a mutable reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

Source

impl RealParameter

fn new( name: CapeStringImpl, description: CapeStringImpl, is_input: bool, shared_unit_data: Rc<RefCell<SharedUnitData>>, default_value: f64, minimum_value: f64, maximum_value: f64, dimensionality: Vec<f64>, ) -> Self